@@ -23,10 +23,9 @@ from lean.click import LeanCommand, PathParameter
 from lean.constants import DEFAULT_ENGINE_IMAGE
 from lean.container import container
 from lean.models.api import QCMinimalOrganization
-from lean.models.config import DebuggingMethod
-from lean.models.data_providers import all_data_providers
-from lean.models.data_providers.quantconnect import QuantConnectDataProvider
+from lean.models.utils import DebuggingMethod
 from lean.models.logger import Option
+from lean.models.data_providers import QuantConnectDataProvider, all_data_providers
 
 
 # The _migrate_* methods automatically update launch configurations for a given debugging method.
@@ -159,7 +158,7 @@ def _migrate_csharp_rider(project_dir: Path) -> None:
         logger.warn("Your run configuration has been updated to work with the .NET 5 version of LEAN")
         logger.warn("Please restart Rider and start debugging again")
         logger.warn(
-            "See https://www.lean.io/docs/lean-cli/tutorials/backtesting/debugging-local-backtests#05-C-and-Rider for the updated instructions")
+            "See https://www.lean.io/docs/lean-cli/backtesting/debugging#05-C-and-Rider for the updated instructions")
 
         raise click.Abort()
 
@@ -289,7 +288,7 @@ def backtest(project: Path,
 
     \b
     Go to the following url to learn how to debug backtests locally using the Lean CLI:
-    https://www.lean.io/docs/lean-cli/tutorials/backtesting/debugging-local-backtests
+    https://www.lean.io/docs/lean-cli/backtesting/debugging
 
     By default the official LEAN engine image is used.
     You can override this using the --image option.
