@@ -18,7 +18,7 @@ import click
 from docker.errors import APIError
 from docker.types import Mount
 from lean.click import LeanCommand, PathParameter
-from lean.constants import DEFAULT_RESEARCH_IMAGE, GUI_PRODUCT_INSTALL_ID
+from lean.constants import DEFAULT_RESEARCH_IMAGE
 from lean.container import container
 from lean.models.data_providers import QuantConnectDataProvider, all_data_providers
 from lean.components.util.name_extraction import convert_to_class_name
@@ -115,11 +115,6 @@ def research(project: Path,
     if detach or not no_open:
         run_options["on_output"] = lambda chunk: _check_docker_output(chunk, port)
 
-    # Give container an identifiable name when running it from the GUI
-    if container.module_manager().is_module_installed(GUI_PRODUCT_INSTALL_ID):
-        project_id = container.project_config_manager().get_local_id(algorithm_file.parent)
-        run_options["name"] = f"lean_cli_gui_research_{project_id}"
-
     # Make Ctrl+C stop Jupyter Lab immediately
     run_options["stop_signal"] = "SIGKILL"
 
