@@ -17,7 +17,7 @@ from typing import Set, List, Dict
 from lean.components.api.api_client import APIClient
 from lean.components.util.http_client import HTTPClient
 from lean.components.util.logger import Logger
-from lean.constants import MODULES_DIRECTORY, GUI_PRODUCT_ID
+from lean.constants import MODULES_DIRECTORY
 from lean.models.modules import NuGetPackage
 
 
