@@ -12,7 +12,6 @@
 # limitations under the License.
 
 import json
-import os
 import re
 import uuid
 from datetime import datetime
@@ -35,7 +34,6 @@ from lean.constants import MODULES_DIRECTORY, TERMINAL_LINK_PRODUCT_ID
 from lean.models.docker import DockerImage
 from lean.models.utils import DebuggingMethod
 
-
 class LeanRunner:
     """The LeanRunner class contains the code that runs the LEAN engine locally."""
 
@@ -136,6 +134,11 @@ class LeanRunner:
         self._project_manager.copy_code(algorithm_file.parent, output_dir / "code")
 
         # Run the engine and log the result
+        # Run as a subprocess to capture the output before logging it
+
+        # Format error messages for cleaner output logs
+        run_options["format_output"] = self.format_error_before_logging
+        
         success = self._docker_manager.run_image(image, **run_options)
 
         cli_root_dir = self._lean_config_manager.get_cli_root_directory()
@@ -207,8 +210,7 @@ class LeanRunner:
         if not storage_dir.exists():
             storage_dir.mkdir(parents=True)
 
-        lean_config["debug-mode"] = self._logger.debug_logging_enabled \
-                                    and os.environ.get("QC_LOCAL_GUI", "false") != "true"
+        lean_config["debug-mode"] = self._logger.debug_logging_enabled
         lean_config["data-folder"] = "/Lean/Data"
         lean_config["results-destination-folder"] = "/Results"
         lean_config["object-store-root"] = "/Storage"
@@ -303,12 +305,8 @@ class LeanRunner:
                 "python /copy_csharp_dependencies.py /Compile/obj/ModulesProject/project.assets.json")
 
         # Set up language-specific run options
-        if algorithm_file.name.endswith(".py"):
-            self.set_up_python_options(project_dir, run_options)
-        else:
-            if not set_up_common_csharp_options_called:
-                self.set_up_common_csharp_options(run_options)
-            self.set_up_csharp_options(project_dir, run_options, release)
+        self.setup_language_specific_run_options(run_options, project_dir, algorithm_file,
+                                            set_up_common_csharp_options_called, release)
 
         # Save the final Lean config to a temporary file so we can mount it into the container
         config_path = self._temp_manager.create_temporary_directory() / "config.json"
@@ -339,6 +337,16 @@ class LeanRunner:
         :param project_dir: the path to the project directory
         :param run_options: the dictionary to append run options to
         """
+
+        # Compile python files
+        source_files = self._project_manager.get_source_files(project_dir)
+        source_files = [file.relative_to(
+            project_dir).as_posix() for file in source_files]
+        source_files = [f'"/LeanCLI/{file}"' for file in source_files]
+
+        run_options["commands"].append(
+            f"python -m compileall {' '.join(source_files)}")
+            
         # Mount the project directory
         run_options["volumes"][str(project_dir)] = {
             "bind": "/LeanCLI",
@@ -686,3 +694,30 @@ for library_id, library_data in project_assets["targets"][project_target].items(
 
         if len(zip_names) == 0 or (datetime.now() - datetime.strptime(zip_names[0], "%Y%m%d")).days > 7:
             lean_config[config_key] = disk_provider
+
+    def setup_language_specific_run_options(self, run_options, project_dir, algorithm_file,
+                                            set_up_common_csharp_options_called, release) -> None:
+        # Set up language-specific run options
+        if algorithm_file.name.endswith(".py"):
+            self.set_up_python_options(project_dir, run_options)
+        else:
+            if not set_up_common_csharp_options_called:
+                self.set_up_common_csharp_options(run_options)
+            self.set_up_csharp_options(project_dir, run_options, release)
+
+    def format_error_before_logging(self, chunk: str):
+        from lean.components.util import compiler
+        errors = []
+
+        # As we don't have algorithm type information. We can check errors for both
+        # Python
+        jsonString = compiler.get_errors("python", chunk)
+        jsonData = json.loads(jsonString)
+        errors.extend(jsonData["aErrors"])
+        # CSharp
+        jsonString = compiler.get_errors("csharp", chunk)
+        jsonData = json.loads(jsonString)
+        errors.extend(jsonData["aErrors"])
+
+        for error in errors:
+            self._logger.info(error)
\ No newline at end of file
